containertools.repeat_contents_of_container
===========================================

.. autofunction:: abjad.tools.containertools.repeat_contents_of_container.repeat_contents_of_container
   :noindex:
